=== modified file 'CMakeLists.txt'
--- CMakeLists.txt	2016-01-31 22:01:01 +0000
+++ CMakeLists.txt	2016-01-31 22:59:44 +0000
@@ -5,7 +5,7 @@
 set (CMAKE_MODULE_PATH ${CMAKE_MODULE_PATH} ${CMAKE_CURRENT_SOURCE_DIR}/cmake)
 
 option (DEBUG "Enable debug flags and macros in project." TRUE)
-option (USE_GC "Enable/disable the LibGC garbage colletor." TRUE)
+option (USE_GC "Enable/disable the LibGC garbage colletor." FALSE)
 
 find_package (Threads REQUIRED)
 if (USE_GC)

=== modified file 'libssts/defs.h'
--- libssts/defs.h	2016-01-31 22:01:01 +0000
+++ libssts/defs.h	2016-01-31 22:59:44 +0000
@@ -54,6 +54,9 @@
 
 /* ***************************** GENERIC MACROS ***************************** */
 
+/** @def
+ */
+
 /**
  * @def S_DEPRECATED
  * Mark function as deprecated.
@@ -141,7 +144,6 @@
   #endif
 #endif
 
-
 /**
  * FALSE has the absolute value of 0, it is used in as a way to represent a
  * false value. A "not" value.
@@ -282,26 +284,26 @@
  * @se STypeName
  */
 typedef enum {
-  S_TYPE_NONE = 0,
-  S_TYPE_INT,
-  S_TYPE_LONG,
-  S_TYPE_SHORT,
-  S_TYPE_CHAR,
-  S_TYPE_WCHAR,
-  S_TYPE_UCHAR, /**< char32_t/uchar */
-  S_TYPE_UINT,
-  S_TYPE_ULONG,
-  S_TYPE_USHORT,
-  S_TYPE_BOOLEAN,
-  S_TYPE_STRING,
-  S_TYPE_WSTRING, /**< Platform specific wchar_t */
-  S_TYPE_USTRING, /**< char32_t String.*/
-  S_TYPE_UNUSED_0,
-  S_TYPE_UNUSED_1,
-  S_TYPE_UNUSED_2,
-  S_TYPE_POINTER,
-  S_TYPE_OBJECT,
-  S_TYPE_INVALID
+  S_TYPE_NONE = 0, /**< Not a type. */
+  S_TYPE_INT, /**< @ref sint */
+  S_TYPE_LONG, /**< @ref slong */
+  S_TYPE_SHORT, /**< @ref sshort */
+  S_TYPE_CHAR, /**< @ref schar */
+  S_TYPE_WCHAR, /**< @deprecated wide char (wchar_t) */
+  S_TYPE_UCHAR, /**< @ref suchar */
+  S_TYPE_UINT, /**< @ref suint */
+  S_TYPE_ULONG, /**< @ref sulong */
+  S_TYPE_USHORT, /**< @ref sushort */
+  S_TYPE_BOOLEAN, /**< @ref sboolean */
+  S_TYPE_STRING, /**< a string of @ref schar s */
+  S_TYPE_WSTRING, /**< @deprecated  Platform specific wchar_t string */
+  S_TYPE_USTRING, /**< a string of @ref suchar s */
+  S_TYPE_UNUSED_0, /**< */
+  S_TYPE_UNUSED_1, /**< */
+  S_TYPE_UNUSED_2, /**< */
+  S_TYPE_POINTER, /**< @ref spointer */
+  S_TYPE_OBJECT, /**< @ref SObject */
+  S_TYPE_INVALID /** Invalid type. */
 } SType;
 
 /** @brief
@@ -381,6 +383,56 @@
 
 
 /**
+ * @defgroup MemoryM Memory Management
+ * @addtogroup MemoryM
+ * @{
+ * @brief Memory management stuff.
+ *
+ * By default libssts does not use a GC, it can be enabled with by setting the
+ * USE_GC switch in cmake.
+ * 
+ * Even if you have GC enabled, it is important to make sure that when you do
+ * not use the GC it will still cleanup all the pointers.
+ *
+ * General rule: for every @ref s_malloc() have a @ref s_free() even if you know
+ * you are running a GC.
+ */
+
+/**
+ * @def s_malloc 
+ * By default this is this is just a normal call to malloc. But with
+ * GC enabled it will use GC_MALLOC to allocate memory.
+ */
+
+/**
+ * @def s_free
+ * by default this acts just as a normal call to free. If GC is enabled this
+ * will do nothing.
+ */
+
+/**
+ * @def s_realloc
+ * By default this will act just as a normal call to realloc. But if GC is
+ * enabled this will use GC_REALLOC.
+ */
+
+#if USE_GC
+  #define s_mm_init() GC_INIT()
+  #define s_mm_cleanup() 
+  #define s_malloc(s) GC_MALLOC(s)
+  #define s_free(o)
+  #define s_realloc(o, s) GC_REALLOC(o, s)
+#else
+  #define s_mm_init()
+  #define s_mm_cleanup()
+  #define s_malloc(s) malloc(s)
+  #define s_free(o) free(o)
+  #define s_realloc realloc(o, s)
+#endif /* USE_GC */
+
+/** @} */
+
+/**
  * @}
  */
 

